aboutsummaryrefslogtreecommitdiffstats
path: root/src/llvm.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/llvm.cpp')
-rw-r--r--src/llvm.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/llvm.cpp b/src/llvm.cpp
index fdb9783..5b6d69f 100644
--- a/src/llvm.cpp
+++ b/src/llvm.cpp
@@ -1,18 +1,18 @@
/* Tuplr: A programming language
* Copyright (C) 2008-2009 David Robillard <dave@drobilla.net>
*
* Tuplr is free software: you can redistribute it and/or modify it under
* the terms of the GNU Affero General Public License as published by the
* Free Software Foundation, either version 3 of the License, or (at your
* option) any later version.
*
* Tuplr is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General
* Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
- * along with Tuplr. If not, see <http://www.gnu.org/licenses/>.
+ * along with Resp. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file
@@ -39,7 +39,7 @@
#include "llvm/Target/TargetData.h"
#include "llvm/Target/TargetSelect.h"
#include "llvm/Transforms/Scalar.h"
-#include "tuplr.hpp"
+#include "resp.hpp"
using namespace llvm;
using namespace std;
@@ -54,7 +54,7 @@ struct LLVMEngine : public Engine {
: builder(context)
{
InitializeNativeTarget();
- module = new Module("tuplr", context);
+ module = new Module("resp", context);
emp = new ExistingModuleProvider(module);
engine = EngineBuilder(module).create();
opt = new FunctionPassManager(emp);
@@ -71,7 +71,7 @@ struct LLVMEngine : public Engine {
std::vector<const Type*> argsT(1, Type::getInt32Ty(context)); // unsigned size
FunctionType* funcT = FunctionType::get(PointerType::get(Type::getInt8Ty(context), 0), argsT, false);
alloc = Function::Create(funcT, Function::ExternalLinkage,
- "tuplr_gc_allocate", module);
+ "resp_gc_allocate", module);
}
~LLVMEngine()
@@ -227,7 +227,7 @@ struct LLVMEngine : public Engine {
};
Engine*
-tuplr_new_llvm_engine()
+resp_new_llvm_engine()
{
return new LLVMEngine();
}
@@ -1,18 +1,18 @@
-/* Tuplr: A programming language
+/* Resp: A programming language
* Copyright (C) 2008-2009 David Robillard <dave@drobilla.net>
*
@@ -1,18 +1,18 @@
* Copyright (C) 2008-2009 David Robillard <dave@drobilla.net>
*
- * Tuplr is free software: you can redistribute it and/or modify it under
+ * Resp is free software: you can redistribute it and/or modify it under
* the terms of the GNU Affero General Public License as published by the
* Free Software Foundation, either version 3 of the License, or (at your
@@ -1,18 +1,18 @@
* option) any later version.
*
- * Tuplr is distributed in the hope that it will be useful, but WITHOUT
+ * Resp is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General